package com.ruoyi.project.configuration.service;

import java.util.List;

import com.ruoyi.project.configuration.domain.TMatterFeature;

/**
 * 危害物质-危害性质Service接口
 *
 * @author ruoyi
 * @date 2021-12-28
 */
public interface ITMatterFeatureService {

    public List<String> queryByIds(String[] ids);

    /**
     * 查询危害物质-危害性质
     *
     * @param id 危害物质-危害性质ID
     * @return 危害物质-危害性质
     */
    public TMatterFeature selectTMatterFeatureById(Long id);

    /**
     * 查询危害物质-危害性质列表
     *
     * @param tMatterFeature 危害物质-危害性质
     * @return 危害物质-危害性质集合
     */
    public List<TMatterFeature> selectTMatterFeatureList(TMatterFeature tMatterFeature);

    /**
     * 新增危害物质-危害性质
     *
     * @param tMatterFeature 危害物质-危害性质
     * @return 结果
     */
    public int insertTMatterFeature(TMatterFeature tMatterFeature);

    /**
     * 修改危害物质-危害性质
     *
     * @param tMatterFeature 危害物质-危害性质
     * @return 结果
     */
    public int updateTMatterFeature(TMatterFeature tMatterFeature);

    /**
     * 批量删除危害物质-危害性质
     *
     * @param ids 需要删除的危害物质-危害性质ID
     * @return 结果
     */
    public int deleteTMatterFeatureByIds(Long[] ids);

    /**
     * 删除危害物质-危害性质信息
     *
     * @param id 危害物质-危害性质ID
     * @return 结果
     */
    public int deleteTMatterFeatureById(Long id);
}
